@@ -1,7 +1,7 @@
 package Data::Dmp;
 
-our $DATE = '2016-03-31'; # DATE
-our $VERSION = '0.15'; # VERSION
+our $DATE = '2016-04-29'; # DATE
+our $VERSION = '0.16'; # VERSION
 
 use 5.010001;
 use strict;
@@ -88,7 +88,9 @@ sub _dump {
     if ($ref eq '') {
         if (!defined($val)) {
             return "undef";
-        } elsif (looks_like_number($val)) {
+        } elsif (looks_like_number($val) &&
+                     $val !~ /\A0[0-9]+\z/ # avoid being interpreted as octal
+                 ) {
             return $val;
         } else {
             return _double_quote($val);
@@ -130,7 +132,7 @@ sub _dump {
         my $i = 0;
         for (sort keys %$val) {
             $res .= "," if $i++;
-            my $k = /\W/ ? _double_quote($_) : $_;
+            my $k = /\A0[0-9]+\z|\W/ ? _double_quote($_) : $_;
             my $v = _dump($val->{$_}, "$subscript\{$k}");
             $res .= "$k=>$v";
         }
@@ -191,7 +193,7 @@ Data::Dmp - Dump Perl data structures as Perl code
 
 =head1 VERSION
 
-This document describes version 0.15 of Data::Dmp (from Perl distribution Data-Dmp), released on 2016-03-31.
+This document describes version 0.16 of Data::Dmp (from Perl distribution Data-Dmp), released on 2016-04-29.
 
 =head1 SYNOPSIS
 
@@ -253,21 +255,21 @@ Note that without the pragmas, the dump might be incorrect.
 
  [1..10]:
                       Rate    Data::Dump Data::Dumper Data::Dmp
- Data::Dump    13626+-20/s            --       -71.8%    -78.3%
- Data::Dumper  48334+-62/s 254.72+-0.69%           --    -23.0%
- Data::Dmp    62790+-130/s   360.8+-1.1% 29.91+-0.31%        --
+ Data::Dump    28512+-41/s            --       -68.8%    -76.8%
+ Data::Dumper 91480+-110/s 220.85+-0.61%           --    -25.6%
+ Data::Dmp    122891+-49/s 331.02+-0.65% 34.34+-0.17%        --
  
  [1..100]:
-                         Rate  Data::Dump    Data::Dmp Data::Dumper
- Data::Dump   1800.67+-0.86/s          --       -79.4%       -82.5%
- Data::Dmp         8731+-63/s 384.9+-3.5%           --       -15.1%
- Data::Dumper     10277+-37/s 470.8+-2.1% 17.72+-0.95%           --
+                        Rate    Data::Dump   Data::Dmp Data::Dumper
+ Data::Dump    3397.9+-5.5/s            --      -77.5%       -78.1%
+ Data::Dmp    15091.2+-5.5/s 344.13+-0.74%          --        -2.8%
+ Data::Dumper    15532+-51/s   357.1+-1.7% 2.92+-0.34%           --
  
  Some mixed structure:
-                        Rate    Data::Dump    Data::Dmp Data::Dumper
- Data::Dump    4810.1+-4.8/s            --       -68.8%       -80.0%
- Data::Dmp    15421.8+-6.2/s 220.62+-0.35%           --       -35.9%
- Data::Dumper    24055+-31/s 400.09+-0.81% 55.98+-0.21%           --
+                     Rate Data::Dump    Data::Dmp Data::Dumper
+ Data::Dump    8319+-15/s         --       -70.3%       -81.1%
+ Data::Dmp    27994+-71/s  236.5+-1%           --       -36.4%
+ Data::Dumper 44024+-37/s  429.2+-1% 57.26+-0.42%           --
 
 =head1 FUNCTIONS
 
